import pandas as pd
import json
import argparse
import re, os, time
import glob


def get_full_text(row):
    if row['extended_tweet'].notna():
        return row['extended_tweet']['full_text']
    else:
        return row['text']


def normalizeWord(token):
    lowercased_token = token.lower()
    if token.startswith("@") and len(token)>1:
        return "@USER"
    elif len(token) >=3:
        if token[1] == "@":
            return token[0]+"@USER"
    if lowercased_token.startswith("http") or lowercased_token.startswith("www"):
        return "HTTPURL"
    for i in ['.com', '.edu', '.gov']:
        if i in lowercased_token:
            return "HTTPURL"
    else:
        return token
    
    
def process_data(geo_data):
    tweet_tokens = []
    for i in range(geo_data.shape[0]):
        text = geo_data['tweet'].iloc[i]
        text = text.replace('\n',' ').replace('\r',' ').replace("’", "'").replace("…", "...")
        words = text.split(' ')
        words = [normalizeWord(word) for word in words]
        new_text = ' '.join(words)
        geo_data.at[i, 'tweet'] = text
        temp = list(filter(None, re.split('([,.!?:()[\]"\s+])', new_text)))
        tweet_split = list(filter(str.strip, temp))
        tweet_tokens.append(tweet_split)
    geo_data['tweet_token'] = tweet_tokens
    return geo_data
    

def mainPreprocess():
    output_file_name = "processed_data"
    input_dir = "tmp/"
    output_dir = "tmp/"
    chunk_size = 100000
    max_read_size = None  

    to_extract = ['id', 'text', 'in_reply_to_status', 'user',
                 'geo', 'coordinates', 'place', 'timestamp_ms', 
                  'retweeted', 'extended_tweet']
                  
    chunk = 0
    count = 0
    total_count = 0
    file_count = 0;
    path = os.path.join(input_dir, 'tweets_*.txt')

    file_list = glob.glob(path)

    for file_name in file_list:
        file_name = file_name.split('/')[-1];
        file_path = os.path.join(input_dir, file_name)
        file_count += 1

        with open(file_path, 'r') as infile:

            for e, line in enumerate(infile):

                if count == 0:
                    tweet_data = []

                try:
                    tmp = json.loads(line)

                    if (tmp['lang'] == 'en') & ('retweeted_status' not in tmp.keys()):
                        subset_tmp = {key: tmp[key] for key, value in tmp.items() if key in to_extract}
                        tweet_data.append(subset_tmp)
                        count += 1

                except:
                    print(f'line {e} in file {file_path} cannot be processed')

            if count != 0:

                tweet_data = pd.DataFrame(tweet_data)

                tweet_data['text'] = tweet_data['text'].replace('\n', ' ', regex=True)
                tweet_data['text'] = tweet_data['text'].replace('\r', ' ', regex=True)
                tweet_data['tweet'] = tweet_data['text']

                tweet_data.drop_duplicates(subset=['tweet'], inplace=True)
                tweet_data.reset_index(inplace=True, drop=True)

                tweet_data = process_data(tweet_data)
                
                output_file_name = input_file_name.split('.')[0] + f'_chunk-{chunk}.csv' if file_name is None else file_name + f'_chunk-{chunk}.csv'
                output_file_path = os.path.join(output_dir, output_file_name)

                tweet_data.to_csv(output_file_path, index=False)
                print(f'output chunk {chunk}, size is {tweet_data.shape[0]}, path is {output_file_path}\n')

                chunk += 1
                total_count += tweet_data.shape[0]
                count = 0
                del tweet_data
    
    
