import * as d3 from 'd3';


d3.csv("https://raw.githubusercontent.com/johnccarroll/mqp/main/src/components/final.csv?token=GHSAT0AAAAAABO2BFYNACSIYCS2CSQ3QEISYPJ5OCA", function(data) {
    // define count object that holds count for each symptom type

    var countObj = {};


// count how much each symptom type occurs in list and store in countObj
    data.forEach(function(d) {
        var symptom = d.symptom_tokens;
        if(countObj[symptom] == undefined) {
            countObj[symptom] = 0;
        } else {
            countObj[symptom] = countObj[symptom] + 1;
        }
    });

// now store the count in each data member
    data.forEach(function(d) {
        var symptom = d.symptom_tokens;
        d.count = countObj[symptom];
    });


// sort data desc
    data.sort(function(a, b){
        return b.count - a.count;
    })

// slice data down to the first 33% of the results
    data = data.slice(0, ((data.length/-8)));


    // set the dimensions and margins of the graph
    var margin = {top: 20, right: 30, bottom: 40, left: 150},
        width = 500 - margin.left - margin.right,
        height = 5000 - margin.top - margin.bottom;

// append the svg object to the body of the page
    var svg = d3.select("#symptom")
        .append("svg")
        .attr("width", width + margin.left + margin.right)
        .attr("height", height + margin.top + margin.bottom)
        .attr("style", "outline: thin solid red;")
        .append("g")
        .attr("transform",
            "translate(" + margin.left + "," + margin.top + ")");



    // Add X axis
    var x = d3.scaleLinear()
        .domain([0, 400])
        .range([ 0, width]);
    svg.append("g")
        .attr("transform", "translate(0," + height + ")")
        .call(d3.axisBottom(x))
        .selectAll("text")
        .attr("transform", "translate(-10,0)rotate(-45)")
        .style("text-anchor", "end");

    // Y axis
    var y = d3.scaleBand()
        .range([ 0, height ])
        .domain(data.map(function(d) { return d.symptom_tokens; }))
        .padding(.1);
    svg.append("g")
        .call(d3.axisLeft(y))

    //grid lines
    svg.append('g')
        .attr('class', 'grid')
        .attr('transform', `translate(0, ${height})`)
        .call(d3.axisBottom()
            .scale(x)
            .tickSize(-height, 0, 0)
            .tickFormat(''))

    svg.append('g')
        .attr('class', 'grid')
        .call(d3.axisLeft()
            .scale(y)
            .tickSize(-width, 0, 0)
            .tickFormat(''))


    //Bars
    var bar = svg.selectAll("myRect")
        .data(data)
        .enter()
        .append("rect")
        .filter(function(d) { return d.symptom_tokens != "[-1]" })
        .attr("x", x(0) )
        .attr("y", function(d) { return y(d.symptom_tokens); })
        .attr("width", function(d) { return x(d.count); })
        .attr("height", y.bandwidth() )
        .attr("fill", "red")
        .attr("class", "bar")
        .on("mouseover", d => mouseover(d))
        .on("mouseout", mouseout);

    var div = d3.select("body").append("div")
        .attr("class", "tooltip")
        .style("display", "none");

    svg.selectAll("text.bar")
        .data(data)
        .enter().append("text")
        .attr("class", "bar")
        .attr("text-anchor", "middle")
        .attr("x", function(d) { return x(d.count) + 15; })
        .attr("y", function(d) { return y(d.symptom_tokens) + 15; })
        .text(function(d) { return d.count; });


    function mouseover(d) {
        div.style("display", "inline");
        div.text()
    }


    function mouseout() {
        div.style("display", "none");
    }

    svg.append("text")
        .attr("x", (width / 2))
        .attr("y", 0 - (margin.top / 4))
        .attr("text-anchor", "middle")
        .style("font-size", "16px")
        .style("text-decoration", "underline")
        .text("Symptom Count Graph");




});
