import React, { useState, useEffect } from "react";
import {ComposableMap, Geographies, Geography, ZoomableGroup} from "react-simple-maps";
import {scaleLinear, scaleQuantize} from "d3-scale";
import { csv } from "d3-fetch";

const geoUrl = "https://cdn.jsdelivr.net/npm/us-atlas@3/counties-10m.json";

const colorScale = scaleQuantize()
    .domain([1, 10])
    .range([
        "#ffedea",
        "#ffcec5",
        "#ffad9f",
        "#ff8a75",
        "#ff5533",
        "#e2492d",
        "#be3d26",
        "#9a311f",
        "#782618"
    ]);

const colorScale2 = scaleLinear()
    .domain([0.00, 15.00])
    .range(["#ffedea", "#ff5233"])


const MapChart = () => {
    const [state, setState] = useState({data:[]});

    useEffect(() => {
        // https://www.bls.gov/lau/
        csv("finalMapData.csv").then(counties => {
            setState({data:counties});
        });
    }, []);


    return (
        <>
            <h1>
                Current Food Poisoning Cases
            </h1>
            <h1>
                {state.curSelection && handleJsonHeader(state.curSelection)}
            </h1>
            <b>
                {state.curSelection && handleJsonBody(state.curSelection)[0]}
                <br></br>
                {state.curSelection && handleJsonBody(state.curSelection)[1]}
            </b>
            <ComposableMap projection="geoAlbersUsa">
                <ZoomableGroup zoom={1}>
                    <Geographies geography={geoUrl}>
                        {({ geographies }) =>
                            geographies.map(geo => {
                                const cur = state.data.find(s => s.id === geo.id);
                                return (
                                    <Geography
                                        key={geo.rsmKey}
                                        geography={geo}
                                        fill={cur ? colorScale2(cur.total_cases) : "#EEE"}
                                        onClick={()=>setState({data:state.data, curSelection:cur})}
                                    />
                                );
                            })
                        }
                    </Geographies>
                </ZoomableGroup>
            </ComposableMap>
        </>
    );
};
function handleJsonHeader(json){
    var str = JSON.stringify(json);
    const arr = str.split('"')
    return arr[11]
}
function handleJsonBody(json){
    var str = JSON.stringify(json);
    const arr = str.split('"')
    const body = [];
    const countyNum = "County Number: " + arr[7];
    const totalCases = "Total Cases: " + arr[19];
    body.push(countyNum, totalCases)
    return body;
}
function handleJsonTweets(json){

}

export default MapChart;
