import React, { useState, useEffect } from 'react';
import * as d3 from 'd3';
import cloud from 'd3-cloud';
import WordCloud from 'react-d3-cloud';
import { scaleOrdinal } from 'd3-scale';
import { schemeCategory10 } from 'd3-scale-chromatic';

// documentation: https://github.com/jasondavies/d3-cloud
// further documentation: https://github.com/Yoctol/react-d3-cloud

function WordCloudMain(wordsInput) {

    console.log("INPUT:",wordsInput);

    var myColor = d3.scaleLinear().domain([1,100]).range(["red", "black"])
    console.log(myColor(3));
    console.log(wordsInput.words.length);

    const [loading, setLoading] = useState(true);

    useEffect(()=>{
        console.log("WORDCLOUD page is loaded");
        setLoading(false);
        console.log(wordsInput)
    }, [wordsInput.selectedOption]);

    return (
        <WordCloud
            data={wordsInput.words}
            width={700}
            height={500}
            font="Times"
            fontStyle="italic"
            fontWeight="bold"
            fontSize={(word) => (Math.log2(word.value) * 5)+50}
            padding={5}
            rotate={0}
            random={Math.random}
            fill={(word) => (myColor(word.value))} //myColor(d)
            onWordClick={(event, d) => {
                console.log(`onWordClick: ${d.text}`);
            }}
            onWordMouseOver={(event, d) => {
                console.log(`onWordMouseOver: ${d.text}`);
            }}
            onWordMouseOut={(event, d) => {
                console.log(`onWordMouseOut: ${d.text}`);
            }} />
    );
}

export default WordCloudMain;
