import React, {useState, useEffect} from "react";
import WordCloudMain from '../components/wordcloud/wordCloud';
import DropDown from '../components/dropdown/dropdown';
import { useStates } from 'react-us-states';
import './Learn.css';

export default function Learn() {
    const [loading, setLoading] = useState(true);
    const [selectedOption, setSelectedOption] = useState('INGREDIENTS');
    const [selectedYear, setSelectedYear] = useState('2022');
    const [selectedMonth, setSelectedMonth] = useState('JANUARY');
    const [selectedState, setSelectedState] = useState('NEW YORK');
    const [symptomData, setSymptomData] = useState([""]);
    const [ingredientData, setIngredientData] = useState([""]);
    const states = useStates();
    let wordData=[];
    let parsedInput;
    let symptomArray=[];
    let ingredientsArray=[];

    wordData = filterWords(pickList(selectedOption, selectedYear));

    useEffect(()=>{
        console.log("loading site")
        getSymptoms()
        getIngredients()
        setLoading(false);
        wordData = filterWords(pickList(selectedOption, selectedYear));
    }, [selectedOption]);
    
    function getSymptoms() {
        fetch('https://mqp-backend-l3sh3.ondigitalocean.app/symptoms')
          .then(response => {
            return response.text();
          })
          .then(data => {
            parsedInput= Object.values(JSON.parse(data)).map((words)=> words['symptom_token'].replace(/[\[ \] " ']/g, '').split(','))
            Object.values(parsedInput).map((words) => words.map((word)=> symptomArray.push(word)))
            console.log(symptomArray);
            setSymptomData(symptomArray);
          });
      }
    
    function getIngredients() {
        fetch('https://mqp-backend-l3sh3.ondigitalocean.app/ingredients')
          .then(response => {
            return response.text();
          })
          .then(data => {
            parsedInput= Object.values(JSON.parse(data)).map((words)=> words['food_token'].replace(/[\[ \] " ']/g, '').split(','))
            Object.values(parsedInput).map((words) => words.map((word)=> ingredientsArray.push(word)))
            console.log(ingredientsArray);
            setIngredientData(ingredientsArray);
          });
      }

    function changeOption(option){
        setSelectedOption(option);
        console.log("learn: change selected option", option);
    }

    function changeYear(year){
        setSelectedYear(year);
        console.log("learn: change selected year", year);
    }

    function changeMonth(month){
        setSelectedMonth(month);
        console.log("learn: change selected month", month);
    }

    function changeState(state){
        setSelectedState(state);
        console.log("learn: change selected month", state);
    }

    function pickList(selectedOption,selectedYear){
        let locations2020 = ["feature not working"];
        let locations2021 = ["feature not working"];
        let locations2022 = ["feature not working"];

        console.log("call pickList with ", selectedOption);
        if(selectedOption === 'INGREDIENTS'){
            if(selectedYear === '2020'){
                return ingredientData;
            }
            if(selectedYear === '2021'){
                return ingredientData;
            }
            if(selectedYear === '2022'){
                return ingredientData;
            }
        }

        if(selectedOption === 'SYMPTOMS'){
            if(selectedYear === '2020'){
                return symptomData;
            }
            if(selectedYear === '2021'){
                return symptomData;
            }
            if(selectedYear === '2022'){
                return symptomData;
            }
        }

        if(selectedOption === 'COMPANY'){
            if(selectedYear === '2020'){
                return locations2020;
            }
            if(selectedYear === '2021'){
                return locations2021;
            }
            if(selectedYear === '2022'){
                return locations2022;
            }
        
        }
    }


    // get the maximum and then divide the numbers by themseleves and
    // then multiply by 100 to get the 0 to 100 scale 
    function filterWords(words){
        var dict = {};
        var result = [];
        console.log("filtering words", words);
        let maxValue = 0

        words.map((word)=> word.toLowerCase())

        for(let i = 0; i<words.length; i++){
            let word = words[i];
            if(Object.keys(dict).includes(word)){
                dict[word] = dict[word] + 1;
            }
            else{
                dict[word] = 1; 
            }
            if (dict[word]>maxValue){
                maxValue = dict[word]
            }
        }
        console.log("ORIGINAL",dict)


        let uniqueWords = words.filter((x, i, a) => a.indexOf(x) == i);
        let j =0;
        for(let i = 0; i<uniqueWords.length; i++){
            let value = (dict[uniqueWords[i]]/ maxValue)
            if (value > 0.0007){
                result[j] = ({'text':uniqueWords[i], 'value':value*100})
                j = j+1;
            }        
        }

        console.log(result)

        return result;
    }

    return (
        <div className="learn">
            <div className="heading-learn">
                <h2>Explore past outbreaks</h2>
                <h3>Select the year and type of words to explore the most common words used in tweets relating to food borne illnesess</h3>
            </div>
            {!loading && 
                <div className= "wordCloud-master">
                    <div className = "wordCloud-dropdowns">
                        <DropDown id = {'one'} changeOption={changeOption} selectedOption={selectedOption} options={['INGREDIENTS', 'SYMPTOMS', 'COMPANY']}/>
                        <DropDown id = {'two'} changeOption={changeMonth} selectedOption={selectedMonth} options={['JANUARY', 'FEBUARY', 'MARCH', 'APRIL', 'MAY', 'JUNE', 'JULY', 'AUGUST', 'SEPTEMBER', 'OCTOBER', 'NOVEMBER', 'DECEMBER']}/>
                        <DropDown id = {'three'} changeOption={changeYear} selectedOption={selectedYear} options={['2019', '2020', '2021', '2022']}/>
                        <DropDown id = {'four'} changeOption={changeState} selectedOption={selectedState} options={states.map((state)=> state.name.toUpperCase())}/>
                    </div>
                    <WordCloudMain words={wordData} selectedOption={selectedOption}/>
                </div>
            }
        </div>

    );
}